# README #

### Purpose: ###

* The pdm_utils repository provides the source code for pdm_utils Python package, developed in the SEA-PHAGES program to create, update, and maintain MySQL phage genomics databases.

The source code is available on GitHub at https://github.com/SEA-PHAGES/pdm_utils/.

The user guide for the package is available on ReadTheDocs at https://pdm-utils.readthedocs.io/en/latest/.

The pdm_utils Python package is available on PyPI at https://pypi.org/project/pdm-utils/.

### Contribution guidelines: ###

* Please contact us if you have any contributions or suggestions. Details about how to contribute can be found on the user guide.

### Developers: ###

* Travis Mavrich (trm53@pitt.edu) and Christian Gauthier (christian.gauthier@pitt.edu).
